==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SelectAllCheckboxChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectAllCheckboxChangedEventArgsDescription } from "./SelectAllCheckboxChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectAllCheckboxChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectAllCheckboxChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectAllCheckboxChangedEventArgsDescriptionMetadata.a == null) {
                SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectAllCheckboxChangedEventArgsDescriptionMetadata.c(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            SelectAllCheckboxChangedEventArgsDescriptionMetadata.b(a);
            a.aa("SelectAllCheckboxChangedEventArgs", () => new SelectAllCheckboxChangedEventArgsDescription());
            a.z("SelectAllCheckboxChangedEventArgs", SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectAllCheckboxChangedEventArgsDescriptionMetadata, 'SelectAllCheckboxChangedEventArgsDescriptionMetadata');
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = null;
    return SelectAllCheckboxChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SelectAllCheckboxChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectAllCheckboxChangedEventArgsDescription } from "./SelectAllCheckboxChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectAllCheckboxChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectAllCheckboxChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectAllCheckboxChangedEventArgsDescriptionMetadata.a == null) {
                SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectAllCheckboxChangedEventArgsDescriptionMetadata.c(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            SelectAllCheckboxChangedEventArgsDescriptionMetadata.b(a);
            a.ac("SelectAllCheckboxChangedEventArgs", () => new SelectAllCheckboxChangedEventArgsDescription());
            a.ab("SelectAllCheckboxChangedEventArgs", SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectAllCheckboxChangedEventArgsDescriptionMetadata, 'SelectAllCheckboxChangedEventArgsDescriptionMetadata');
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = null;
    return SelectAllCheckboxChangedEventArgsDescriptionMetadata;
})();
